@@ -1,5 +1,5 @@
 # $File: //depot/OurNet-BBS/BBS/MELIX/Article.pm $ $Author: autrijus $
-# $Revision: #13 $ $Change: 1236 $ $DateTime: 2001/06/20 04:21:57 $
+# $Revision: #15 $ $Change: 1460 $ $DateTime: 2001/07/17 22:31:42 $
 
 package OurNet::BBS::MELIX::Article;
 
@@ -7,6 +7,7 @@ use strict;
 use base qw/OurNet::BBS::MAPLE3::Article/;
 use fields qw/_cache/;
 use subs qw/STORE readok writeok/;
+use open IN => ':raw', OUT => ':raw';
 
 BEGIN { __PACKAGE__->initvars() };
 
@@ -33,11 +34,6 @@ sub STORE {
 
         open(my $BODY, '>', $file) or die "cannot open $file: $!";
 
-	if ($^O eq 'MSWin32') {
-	    binmode($BODY); 	 # turn off crlf conversion
-	    $value =~ s/\015//g; # Unix brain damage
-	}
-
         unless (-s $file) {
             my $hdr = $self->{_cache}{header};
 
@@ -59,8 +55,8 @@ sub STORE {
         print $BODY $value;
         close $BODY;
 
-        $self->{btime} = (stat($file))[9];
         $self->{_cache}{$key} = $value;
+	$self->timestamp($file, 'btime');
     }
     else {
 	no warnings 'uninitialized';
@@ -68,12 +64,13 @@ sub STORE {
         $self->{_cache}{$key} = $value;
 
 	my $file = "$self->{basepath}/$self->{board}/$self->{hdrfile}";
+
         open(my $DIR, '+<', $file) or die "cannot open $file for writing";
         seek $DIR, $packsize * $self->{recno}, 0;
         print $DIR pack($packstring, @{$self->{_cache}}{@packlist});
         close $DIR;
 
-        $self->{mtime} = time;
+	$self->timestamp($file);
     }
 }
 
