@@ -1,11 +1,11 @@
 # $File: //depot/OurNet-BBS/BBS/MELIX/User.pm $ $Author: autrijus $
-# $Revision: #4 $ $Change: 1136 $ $DateTime: 2001/06/14 18:12:19 $
+# $Revision: #5 $ $Change: 1387 $ $DateTime: 2001/07/09 16:40:39 $
 
 package OurNet::BBS::MELIX::User;
 
 use base qw/OurNet::BBS::MAPLE3::User/;
 use fields qw/_cache/;
-use subs qw/has_perm/;
+use subs qw/has_perm writeok readok/;
 
 BEGIN { __PACKAGE__->initvars() }
 
@@ -14,4 +14,8 @@ sub has_perm {
     return $_[0]->{userlevel} & &{$_[1]};
 }
 
+sub writeok { 0 }
+sub readok { 1 }
+
 1;
+
