@@ -1,11 +1,12 @@
 # $File: //depot/OurNet-BBS/BBS/PTT/SessionGroup.pm $ $Author: autrijus $
-# $Revision: #4 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $
+# $Revision: #3 $ $Change: 1204 $ $DateTime: 2001/06/18 19:29:55 $
 
 package OurNet::BBS::PTT::SessionGroup;
 
 use base qw/OurNet::BBS::MAPLE2::SessionGroup/;
-use fields qw/_ego _hash/;
-use OurNet::BBS::Base;
+use fields qw/_cache/;
+
+BEGIN { __PACKAGE__->initvars() };
 
 sub refresh_meta {
     die "Session support at PTT now broken"; 
